Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/dataknobs_fsm/api/advanced.py | 544 | 132 | 0 | 76%
src/dataknobs_fsm/api/async_simple.py | 126 | 19 | 0 | 85%
src/dataknobs_fsm/api/simple.py | 125 | 13 | 0 | 90%
src/dataknobs_fsm/cli/commands.py | 0 | 0 | 0 | 100%
src/dataknobs_fsm/cli/main.py | 470 | 215 | 2 | 54%
src/dataknobs_fsm/config/builder.py | 299 | 49 | 0 | 84%
src/dataknobs_fsm/config/loader.py | 281 | 94 | 0 | 67%
src/dataknobs_fsm/config/schema.py | 172 | 15 | 0 | 91%
src/dataknobs_fsm/config/validator.py | 23 | 0 | 0 | 100%
src/dataknobs_fsm/core/arc.py | 206 | 68 | 2 | 67%
src/dataknobs_fsm/core/context_factory.py | 71 | 12 | 0 | 83%
src/dataknobs_fsm/core/data_modes.py | 103 | 3 | 42 | 97%
src/dataknobs_fsm/core/data_wrapper.py | 117 | 58 | 3 | 50%
src/dataknobs_fsm/core/exceptions.py | 45 | 1 | 0 | 98%
src/dataknobs_fsm/core/fsm.py | 248 | 78 | 0 | 69%
src/dataknobs_fsm/core/modes.py | 19 | 0 | 0 | 100%
src/dataknobs_fsm/core/network.py | 247 | 30 | 0 | 88%
src/dataknobs_fsm/core/result_formatter.py | 41 | 0 | 0 | 100%
src/dataknobs_fsm/core/state.py | 173 | 4 | 2 | 98%
src/dataknobs_fsm/core/transactions.py | 210 | 24 | 38 | 89%
src/dataknobs_fsm/execution/async_batch.py | 98 | 39 | 0 | 60%
src/dataknobs_fsm/execution/async_engine.py | 251 | 56 | 0 | 78%
src/dataknobs_fsm/execution/async_stream.py | 116 | 18 | 0 | 84%
src/dataknobs_fsm/execution/base_engine.py | 87 | 25 | 41 | 71%
src/dataknobs_fsm/execution/batch.py | 203 | 84 | 0 | 59%
src/dataknobs_fsm/execution/common.py | 176 | 5 | 2 | 97%
src/dataknobs_fsm/execution/context.py | 187 | 58 | 0 | 69%
src/dataknobs_fsm/execution/engine.py | 368 | 147 | 0 | 60%
src/dataknobs_fsm/execution/history.py | 286 | 18 | 0 | 94%
src/dataknobs_fsm/execution/network.py | 189 | 77 | 0 | 59%
src/dataknobs_fsm/execution/stream.py | 141 | 29 | 0 | 79%
src/dataknobs_fsm/functions/base.py | 143 | 28 | 139 | 80%
src/dataknobs_fsm/functions/library/database.py | 164 | 121 | 0 | 26%
src/dataknobs_fsm/functions/library/streaming.py | 263 | 263 | 0 | 0%
src/dataknobs_fsm/functions/library/transformers.py | 225 | 177 | 0 | 21%
src/dataknobs_fsm/functions/library/validators.py | 206 | 166 | 0 | 19%
src/dataknobs_fsm/functions/manager.py | 257 | 24 | 6 | 91%
src/dataknobs_fsm/io/adapters.py | 483 | 226 | 0 | 53%
src/dataknobs_fsm/io/base.py | 74 | 10 | 72 | 86%
src/dataknobs_fsm/io/utils.py | 139 | 40 | 0 | 71%
src/dataknobs_fsm/patterns/api_orchestration.py | 281 | 281 | 0 | 0%
src/dataknobs_fsm/patterns/error_recovery.py | 395 | 395 | 0 | 0%
src/dataknobs_fsm/patterns/etl.py | 197 | 97 | 0 | 51%
src/dataknobs_fsm/patterns/file_processing.py | 306 | 135 | 0 | 56%
src/dataknobs_fsm/resources/base.py | 119 | 40 | 19 | 66%
src/dataknobs_fsm/resources/database.py | 123 | 90 | 0 | 27%
src/dataknobs_fsm/resources/filesystem.py | 151 | 151 | 0 | 0%
src/dataknobs_fsm/resources/http.py | 176 | 176 | 0 | 0%
src/dataknobs_fsm/resources/manager.py | 274 | 115 | 0 | 58%
src/dataknobs_fsm/resources/pool.py | 166 | 77 | 0 | 54%
src/dataknobs_fsm/resources/properties.py | 113 | 0 | 7 | 100%
src/dataknobs_fsm/storage/base.py | 78 | 25 | 130 | 68%
src/dataknobs_fsm/storage/database.py | 177 | 21 | 2 | 88%
src/dataknobs_fsm/storage/file.py | 14 | 1 | 0 | 93%
src/dataknobs_fsm/storage/memory.py | 23 | 0 | 0 | 100%
src/dataknobs_fsm/streaming/core.py | 366 | 59 | 0 | 84%
src/dataknobs_fsm/streaming/db_stream.py | 203 | 44 | 0 | 78%
src/dataknobs_fsm/streaming/file_stream.py | 281 | 56 | 0 | 80%
src/dataknobs_fsm/utils/file_utils.py | 111 | 2 | 0 | 98%
src/dataknobs_fsm/utils/json_encoder.py | 20 | 12 | 0 | 40%
src/dataknobs_fsm/utils/streaming_file_utils.py | 260 | 30 | 0 | 88%
Total | 11410 | 4233 | 507 | 63%

No items found using the specified filter.